@@ -1,5 +1,5 @@
 """Define endpoints for interacting with Tiles."""
-from typing import Awaitable, Callable, List, Optional
+from typing import Awaitable, Callable, Dict, List, Optional
 
 
 class Tile:  # pylint: disable=too-few-public-methods
@@ -15,11 +15,14 @@ class Tile:  # pylint: disable=too-few-public-methods
         self._request: Callable[..., Awaitable[dict]] = request
         self._user_uuid: Optional[str] = user_uuid
 
-    async def all(self, whitelist: list = None, show_inactive: bool = False) -> list:
+    async def all(
+        self, whitelist: list = None, show_inactive: bool = False
+    ) -> Dict[str, dict]:
         """Get all Tiles for a user's account."""
         list_data: dict = await self._request(
             "get", f"users/{self._user_uuid}/user_tiles"
         )
+
         tile_uuid_list: List[str] = [
             tile["tile_uuid"]
             for tile in list_data["result"]
@@ -29,8 +32,9 @@ class Tile:  # pylint: disable=too-few-public-methods
         tile_data: dict = await self._request(
             "get", "tiles", params=[("tile_uuids", uuid) for uuid in tile_uuid_list]
         )
-        return [
-            tile
-            for tile in tile_data["result"].values()
+
+        return {
+            tile_uuid: tile
+            for tile_uuid, tile in tile_data["result"].items()
             if show_inactive or tile["visible"] is True
-        ]
+        }
